Method: CustomFields::Types::Text::Target::ClassMethods#text_attribute_get

Defined in:
lib/custom_fields/types/text.rb

#text_attribute_get(instance, name) ⇒ Hash

Build a hash storing the raw value for a string custom field of an instance.

Parameters:

  • instance (Object)

    An instance of the class enhanced by the custom_fields

  • name (String)

    The name of the string custom field

Returns:

  • (Hash)

    field name => raw value



42
43
44
# File 'lib/custom_fields/types/text.rb', line 42

def text_attribute_get(instance, name)
  default_attribute_get(instance, name)
end